<TS version="2.1" language="ms">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Klik-kanan untuk edit alamat ataupun label</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Cipta alamat baru</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Baru</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Salin alamat terpilih ke dalam sistem papan klip</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Salin</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Tutup</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Padam alamat semasa yang dipilih dari senaraiyang dipilih dari senarai</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Masukkan alamat atau label untuk carian
</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>
Alihkan fail data ke dalam tab semasa</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Padam</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Pilih alamat untuk hantar koin kepada</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Pilih alamat untuk menerima koin dengan</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Pilih</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">alamat-alamat penghantaran</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">alamat-alamat penerimaan</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Ini adalah alamat Bitcoin anda untuk pembayaran. Periksa jumlah dan alamat penerima sebelum membuat penghantaran koin sentiasa.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Salin Aamat</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Salin &amp; Label</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Eskport Senarai Alamat</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Terdapat ralat semasa cubaan menyimpan senarai alamat kepada %1. Sila cuba lagi.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Mengeksport Gagal</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Alamat</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tiada label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog frasa laluan</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>memasukkan frasa laluan</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Frasa laluan baru</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ulangi frasa laluan baru</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Dompet encrypt</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Operasi ini perlukan frasa laluan dompet anda untuk membuka kunci dompet.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Membuka kunci dompet</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Menukar frasa laluan</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Mengesahkan enkripsi dompet</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Amaran: Jika anda enkripkan dompet anda dan hilangkan frasa laluan, anda akan &lt;b&gt;ANDA AKAN HILANGKAN SEMUA BITCOIN ANDA&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Anda pasti untuk membuat enkripsi dompet anda?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Dompet dienkripsi</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">PENTING: Apa-apa sandaran yang anda buat sebelum ini untuk fail dompet anda hendaklah digantikan dengan fail dompet enkripsi yang dijana baru. Untuk sebab-sebab keselamatan , sandaran fail dompet yang belum dibuat enkripsi sebelum ini akan menjadi tidak berguna secepat anda mula guna dompet enkripsi baru.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Enkripsi dompet gagal</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Enkripsi dompet gagal kerana ralat dalaman. Dompet anda tidak dienkripkan.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Frasa laluan yang dibekalkan tidak sepadan.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Pembukaan kunci dompet gagal</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Frasa laluan dimasukki untuk dekripsi dompet adalah tidak betul.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Frasa laluan dompet berjaya ditukar.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Amaran: Kunci Caps Lock buka!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Diharamkan sehingga</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Gambaran Keseluruhan</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Tunjuk gambaran keseluruhan umum dompet</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksi</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Menyemak imbas sejarah transaksi</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Berhenti aplikasi</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Mengenai%1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Menunjuk informasi mengenai%1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Mengenai &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Menunjuk informasi megenai Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Mengubah suai pilihan konfigurasi untuk %1</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">dompet</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Aktiviti rangkaian dilumpuhkan</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Menghantar koin kepada alamat Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Wallet sandaran ke lokasi lain</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Tukar kata laluan untuk dompet disulitkan</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>hantar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>terima</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;tunjuk/sembunyi</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>tunjuk atau sembunyi tetingkap utama</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>sulitkan kata laluan milik peribadi anda</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>sahkan mesej bersama alamat bitcoin anda untuk menunjukkan alamat ini anda punya</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Sahkan mesej untuk memastikan mereka telah ditandatangani dengan alamat Bitcoin yang ditentukan</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>fail</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>tetapan</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>tolong</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Bar alat tab
</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Request payments (generates QR codes and bitcoin: URIs)
</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Tunjukkan senarai alamat dan label yang digunakan
</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Amaran</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Terkini</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Buka Wallet</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Tutup Wallet</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">dompet lalai
</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tiada label)</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">dompet lalai
</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Tutup Wallet</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">dompet</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ralat</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Alamat</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">dompet</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Salin Alamat</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tiada label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Balance:</source>
        <translation>Baki</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tiada label)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation>
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(tiada label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Address</source>
        <translation type="unfinished">Alamat</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Mengeksport Gagal</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">dompet lalai
</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Eksport</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">
Alihkan fail data ke dalam tab semasa</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Ralat</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Baca Selesai</translation>
    </message>
    </context>
</TS>